==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebCancelableEventArgsDescription } from "./WebCancelableEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDescriptionMetadata.a == null) {
                WebCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDescriptionMetadata.c(WebCancelableEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebCancelableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCancelableEventArgsDescriptionMetadata.a);
            WebCancelableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebCancelableEventArgsDetail");
        }
        static d(a) {
            WebCancelableEventArgsDescriptionMetadata.b(a);
            a.aa("WebCancelableEventArgs", () => new WebCancelableEventArgsDescription());
            a.z("WebCancelableEventArgs", WebCancelableEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableEventArgsDescriptionMetadata, 'WebCancelableEventArgsDescriptionMetadata');
    WebCancelableEventArgsDescriptionMetadata.a = null;
    return WebCancelableEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebCancelableEventArgsDescription } from "./WebCancelableEventArgsDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDescriptionMetadata.a == null) {
                WebCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDescriptionMetadata.c(WebCancelableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCancelableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCancelableEventArgsDescriptionMetadata.a);
            WebCancelableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebCancelableEventArgsDetail");
        }
        static d(a) {
            WebCancelableEventArgsDescriptionMetadata.b(a);
            a.ac("WebCancelableEventArgs", () => new WebCancelableEventArgsDescription());
            a.ab("WebCancelableEventArgs", WebCancelableEventArgsDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableEventArgsDescriptionMetadata, 'WebCancelableEventArgsDescriptionMetadata');
    WebCancelableEventArgsDescriptionMetadata.a = null;
    return WebCancelableEventArgsDescriptionMetadata;
})();
